powered by
Load a specific version of groundhog, as available on a given date
meta.groundhog(date)
character string (yyyy-mm-dd), or date value, with the date which determines the version of groundhog to load
# NOT RUN { #Load groundhog as available on 2021-03-12 (v1.3.2) meta.groundhog("2021-03-12") # } # NOT RUN { # }
Run the code above in your browser using DataLab