Learn R Programming

groundhog (version 1.4.0)

toc: Show CRAN publication dates for all versions of a given package

Description

Show CRAN publication dates for all versions of a given package

Usage

toc(pkg, dependencies = FALSE)

Arguments

pkg

(required) package name

dependencies

logical (defaults to FALSE). Should the output contain package dependencies (Imports, Depends and Suggests) for pkg.

Value

a data.frame where each row corresponds to one version of pkg, a date column contains the publication date, and when dependecies=TRUE, columns show package dependencies over time as well.

Examples

Run this code
# NOT RUN {
toc("R")
toc("magrittr")
toc("rio",dependencies = TRUE)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab